//+------------------------------------------------------------------+
//|                                                Exp_RSIOMA_V2.mq5 |
//|                                Copyright  2013,Nikolay Kositsin | 
//|                              Khabarovsk,   farria@mail.redcom.ru | 
//+------------------------------------------------------------------+
#property copyright "Copyright  2013, Nikolay Kositsin"
#property link      "farria@mail.redcom.ru"
#property version   "1.00"
//+---------------------------------------------------+
//|                             |
//+---------------------------------------------------+
enum AlgMode
  {
   breakdown,  //   
   twist,      //   
   cloudtwist  //    
  };
//+---------------------------------------------------+
//|    CXMA                             |
//+---------------------------------------------------+
#include <SmoothAlgorithms.mqh>
//+---------------------------------------------------+
//|                                  | 
//+---------------------------------------------------+
#include <TradeAlgorithms.mqh>
//+---------------------------------------------------+
//|                             |
//+---------------------------------------------------+
enum Applied_price_      //  
  {
   PRICE_CLOSE_ = 1,     // Close
   PRICE_OPEN_,          // Open
   PRICE_HIGH_,          // High
   PRICE_LOW_,           // Low
   PRICE_MEDIAN_,        // Median Price (HL/2)
   PRICE_TYPICAL_,       // Typical Price (HLC/3)
   PRICE_WEIGHTED_,      // Weighted Close (HLCC/4)
   PRICE_SIMPL_,         // Simple Price (OC/2)
   PRICE_QUARTER_,       // Quarted Price (HLOC/4) 
   PRICE_TRENDFOLLOW0_,  // TrendFollow_1 Price 
   PRICE_TRENDFOLLOW1_,  // TrendFollow_2 Price 
   PRICE_DEMARK_         // Demark Price 
  };
//+---------------------------------------------------+
//|                             |
//+---------------------------------------------------+
//+---------------------------------------------------+
//|                           |   
//+---------------------------------------------------+
input double  MM=-0.1;             //       ,   -  
input MarginMode MMMode=LOT;       //    
input int     StopLoss_=1000;      // Stop Loss  
input int     TakeProfit_=2000;    // Take Profit  
input int     Deviation_=10;       // .    
input bool    BuyPosOpen=true;     //     
input bool    SellPosOpen=true;    //     
input bool    BuyPosClose=true;    //     
input bool    SellPosClose=true;   //     
input AlgMode Mode=breakdown;      //     
//+---------------------------------------------------+
//|    RSIOMA_V2            |
//+---------------------------------------------------+
input ENUM_TIMEFRAMES InpInd_Timeframe=PERIOD_H4; //  
input Smooth_Method RSIOMA_Method=MODE_EMA;       //   RSIOMA
input uint RSIOMA=14;                             //   RSIOMA                    
input int RSIOMAPhase=15;                         //   RSIOMA
//--- RSIOMAPhase:  JJMA    -100 ... +100,     ;
//--- RSIOMAPhase:  VIDIA   CMO,  AMA    
input Smooth_Method MARSIOMA_Method=MODE_EMA;     //   MARSIOMA
input uint MARSIOMA=21;                           //   RSIOMA                    
input int MARSIOMAPhase=15;                       //   RSIOMA,
//--- MARSIOMAPhase:  JJMA    -100 ... +100,     ;
//--- MARSIOMAPhase:  VIDIA   CMO,  AMA    
input uint MomPeriod=1;                           //  
input Applied_price_ IPC=PRICE_CLOSE;             //  
input uint MainTrendLong=60;                      //   
input uint MainTrendShort=40;                     //   
input uint SignalBar=1;                           //      
//+---------------------------------------------------+
//---          
int TimeShiftSec;
//---      
int InpInd_Handle;
//---      
int min_rates_total;
//+------------------------------------------------------------------+
//| Expert initialization function                                   |
//+------------------------------------------------------------------+
int OnInit()
  {
//---    RSIOMA_V2
   InpInd_Handle=iCustom(Symbol(),InpInd_Timeframe,"RSIOMA_V2",RSIOMA_Method,RSIOMA,RSIOMAPhase,MARSIOMA_Method,
                         MARSIOMA,MARSIOMAPhase,MomPeriod,IPC,100,0,clrNONE,clrNONE,MainTrendLong,MainTrendShort,clrGreen,clrRed,0);
   if(InpInd_Handle==INVALID_HANDLE)
     {
      Print("      RSIOMA_V2");
      return(INIT_FAILED);
     }
//---          
   TimeShiftSec=PeriodSeconds(InpInd_Timeframe);
//---     
   min_rates_total+=GetStartBars(RSIOMA_Method,RSIOMA,RSIOMAPhase)+int(MomPeriod)+int(RSIOMA+1);
   min_rates_total+=int(3+SignalBar);
//---  
   return(INIT_SUCCEEDED);
  }
//+------------------------------------------------------------------+
//| Expert deinitialization function                                 |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
  {
//---
   GlobalVariableDel_(Symbol());
//---
  }
//+------------------------------------------------------------------+
//| Expert tick function                                             |
//+------------------------------------------------------------------+
void OnTick()
  {
//---       
   if(BarsCalculated(InpInd_Handle)<min_rates_total) return;
//---       IsNewBar()  SeriesInfoInteger()  
   LoadHistory(TimeCurrent()-PeriodSeconds(InpInd_Timeframe)-1,Symbol(),InpInd_Timeframe);
//---   
   static bool Recount=true;
   static bool BUY_Open=false,BUY_Close=false;
   static bool SELL_Open=false,SELL_Close=false;
   static datetime UpSignalTime,DnSignalTime;
   static CIsNewBar NB;
//---    
   if(!SignalBar || NB.IsNewBar(Symbol(),InpInd_Timeframe) || Recount) //     
     {
      //---   
      BUY_Open=false;
      SELL_Open=false;
      BUY_Close=false;
      SELL_Close=false;
      Recount=false;

      switch(Mode)
        {
         case breakdown: //  
           {
            double Hist[2];
            //---      
            if(CopyBuffer(InpInd_Handle,4,SignalBar,2,Hist)<=0) {Recount=true; return;}
            //---    
            if(Hist[1]>MainTrendLong)
              {
               if(BuyPosOpen  &&  Hist[0]<=MainTrendLong) BUY_Open=true;
               if(SellPosClose) SELL_Close=true;
               UpSignalTime=datetime(SeriesInfoInteger(Symbol(),InpInd_Timeframe,SERIES_LASTBAR_DATE))+TimeShiftSec;
              }
            //---    
            if(Hist[1]<MainTrendShort)
              {
               if(SellPosOpen && Hist[0]>=MainTrendShort) SELL_Open=true;
               if(BuyPosClose) BUY_Close=true;
               DnSignalTime=datetime(SeriesInfoInteger(Symbol(),InpInd_Timeframe,SERIES_LASTBAR_DATE))+TimeShiftSec;
              }
           }
         break;

         case twist:// 
           {
            double Hist[3];
            //---      
            if(CopyBuffer(InpInd_Handle,4,SignalBar,3,Hist)<=0) {Recount=true; return;}
            //---    
            if(Hist[1]<Hist[2])
              {
               if(BuyPosOpen && Hist[0]>Hist[1]) BUY_Open=true;
               if(SellPosClose) SELL_Close=true;
               UpSignalTime=datetime(SeriesInfoInteger(Symbol(),InpInd_Timeframe,SERIES_LASTBAR_DATE))+TimeShiftSec;
              }
            //---    
            if(Hist[1]>Hist[2])
              {
               if(SellPosOpen && Hist[0]<Hist[1]) SELL_Open=true;
               if(BuyPosClose) BUY_Close=true;
               DnSignalTime=datetime(SeriesInfoInteger(Symbol(),InpInd_Timeframe,SERIES_LASTBAR_DATE))+TimeShiftSec;
              }
           }
         break;

         case cloudtwist: //   
           {
            double Up[2],Dn[2];
            //---      
            if(CopyBuffer(InpInd_Handle,0,SignalBar,2,Up)<=0) {Recount=true; return;}
            if(CopyBuffer(InpInd_Handle,1,SignalBar,2,Dn)<=0) {Recount=true; return;}
            //---    
            if(Up[1]>Dn[1])
              {
               if(BuyPosOpen   &&   Up[0]<=Dn[0]) BUY_Open=true;
               if(SellPosClose) SELL_Close=true;
               UpSignalTime=datetime(SeriesInfoInteger(Symbol(),InpInd_Timeframe,SERIES_LASTBAR_DATE))+TimeShiftSec;
              }
            //---    
            if(Up[1]<Dn[1])
              {
               if(SellPosOpen && Up[0]>=Dn[0]) SELL_Open=true;
               if(BuyPosClose) BUY_Close=true;
               DnSignalTime=datetime(SeriesInfoInteger(Symbol(),InpInd_Timeframe,SERIES_LASTBAR_DATE))+TimeShiftSec;
              }
           }
         break;
        }
     }
//---  
//---  
   BuyPositionClose(BUY_Close,Symbol(),Deviation_);
//---     
   SellPositionClose(SELL_Close,Symbol(),Deviation_);
//---  
   BuyPositionOpen(BUY_Open,Symbol(),UpSignalTime,MM,MMMode,Deviation_,StopLoss_,TakeProfit_);
//---  
   SellPositionOpen(SELL_Open,Symbol(),DnSignalTime,MM,MMMode,Deviation_,StopLoss_,TakeProfit_);
//---
  }
//+------------------------------------------------------------------+
